@@ -272,6 +272,7 @@ class Recorder(threading.Thread):
         logger.debug('Starting recording thread')
 
         incoming_epoch_suffix = None
+        num_packets = 0
         for packet in core.ublox_packets(self.serial_stream, core.TIMEOUT_DEF):
 
             try:
@@ -284,9 +285,10 @@ class Recorder(threading.Thread):
                 tow = parsed_packet.rcvTow
                 week = parsed_packet.week
                 epoch = weektow_to_datetime(tow, week)
-
+                num_packets += 1
                 incoming_epoch_suffix = self.slice.build_rinex3_epoch(epoch)
-                logger.debug("U-blox RXM_RAWX packet found! Epoch suffix {}".format(incoming_epoch_suffix))
+                if num_packets % 100 == 0:
+                    logger.debug("U-blox RXM_RAWX packet found! Epoch suffix {} , num_packets = {}".format(incoming_epoch_suffix, num_packets))
 
             if not incoming_epoch_suffix:
                 continue
